/* spice-display.c generated by valac 0.20.1.2-ca5c2, the Vala compiler
 * generated from spice-display.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <spice-client.h>
#include <spice-widget.h>
#include <glib/gi18n-lib.h>
#include <config.h>
#include <gio/gio.h>
#include <libxml/uri.h>


#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
typedef struct _BoxesDisplayPrivate BoxesDisplayPrivate;

#define BOXES_TYPE_SPICE_DISPLAY (boxes_spice_display_get_type ())
#define BOXES_SPICE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay))
#define BOXES_SPICE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayClass))
#define BOXES_IS_SPICE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SPICE_DISPLAY))
#define BOXES_IS_SPICE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SPICE_DISPLAY))
#define BOXES_SPICE_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayClass))

typedef struct _BoxesSpiceDisplay BoxesSpiceDisplay;
typedef struct _BoxesSpiceDisplayClass BoxesSpiceDisplayClass;
typedef struct _BoxesSpiceDisplayPrivate BoxesSpiceDisplayPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
#define _g_free0(var) (var = (g_free (var), NULL))
#define __vala_SpiceUsbDevice_free0(var) ((var == NULL) ? NULL : (var = (_vala_SpiceUsbDevice_free (var), NULL)))
#define _g_ptr_array_unref0(var) ((var == NULL) ? NULL : (var = (g_ptr_array_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block54Data Block54Data;
typedef struct _Block55Data Block55Data;
typedef struct _Block56Data Block56Data;
typedef struct _Block57Data Block57Data;
typedef struct _Block58Data Block58Data;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define _xmlFreeURI0(var) ((var == NULL) ? NULL : (var = (xmlFreeURI (var), NULL)))

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 0
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

struct _BoxesDisplay {
	GObject parent_instance;
	BoxesDisplayPrivate * priv;
	GHashTable* displays;
};

struct _BoxesDisplayClass {
	GObjectClass parent_class;
	GtkWidget* (*get_display) (BoxesDisplay* self, gint n);
	GdkPixbuf* (*get_pixbuf) (BoxesDisplay* self, gint n, GError** error);
	void (*set_enable_inputs) (BoxesDisplay* self, GtkWidget* widget, gboolean enable);
	void (*set_enable_audio) (BoxesDisplay* self, gboolean enable);
	gboolean (*should_keep_alive) (BoxesDisplay* self);
	void (*connect_it) (BoxesDisplay* self, GError** error);
	void (*disconnect_it) (BoxesDisplay* self);
	void (*collect_logs) (BoxesDisplay* self, GString* builder);
	GList* (*get_properties) (BoxesDisplay* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	const gchar* (*get_protocol) (BoxesDisplay* self);
	gchar* (*get_uri) (BoxesDisplay* self);
};

struct _BoxesSpiceDisplay {
	BoxesDisplay parent_instance;
	BoxesSpiceDisplayPrivate * priv;
};

struct _BoxesSpiceDisplayClass {
	BoxesDisplayClass parent_class;
};

struct _BoxesSpiceDisplayPrivate {
	SpiceSession* session;
	SpiceGtkSession* gtk_session;
	SpiceAudio* audio;
	gulong channel_new_id;
	gulong channel_destroy_id;
	BoxesBoxConfigSyncProperty* display_sync_properties;
	gint display_sync_properties_length1;
	gint _display_sync_properties_size_;
	BoxesBoxConfigSyncProperty* gtk_session_sync_properties;
	gint gtk_session_sync_properties_length1;
	gint _gtk_session_sync_properties_size_;
	gboolean connected;
	gboolean closed;
	gboolean _resize_guest;
	SpiceMainChannel* main_channel;
	gulong main_event_id;
	gulong main_mouse_mode_id;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _Block54Data {
	int _ref_count_;
	BoxesSpiceDisplay * self;
	SpiceDisplay* display;
};

struct _Block55Data {
	int _ref_count_;
	BoxesSpiceDisplay * self;
	BoxesProperty* usb_property;
};

struct _Block56Data {
	int _ref_count_;
	Block55Data * _data55_;
	SpiceUsbDeviceManager* manager;
};

struct _Block57Data {
	int _ref_count_;
	GPtrArray * self;
	GCompareFunc compare_func;
};

struct _Block58Data {
	int _ref_count_;
	Block56Data * _data56_;
	SpiceUsbDevice* dev;
	GtkSwitch* dev_toggle;
};


static gpointer boxes_spice_display_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_display_get_type (void) G_GNUC_CONST;
GType boxes_spice_display_get_type (void) G_GNUC_CONST;
#define BOXES_SPICE_DISPLAY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayPrivate))
enum  {
	BOXES_SPICE_DISPLAY_DUMMY_PROPERTY,
	BOXES_SPICE_DISPLAY_PROTOCOL,
	BOXES_SPICE_DISPLAY_URI,
	BOXES_SPICE_DISPLAY_CA_CERT,
	BOXES_SPICE_DISPLAY_RESIZE_GUEST
};
static void boxes_spice_display_main_cleanup (BoxesSpiceDisplay* self);
static void _vala_BoxesBoxConfigSyncProperty_array_free (BoxesBoxConfigSyncProperty* array, gint array_length);
static void boxes_spice_display_ui_state_changed (BoxesSpiceDisplay* self);
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
GtkWidget* boxes_display_get_display (BoxesDisplay* self, gint n);
gboolean boxes_spice_display_get_resize_guest (BoxesSpiceDisplay* self);
BoxesSpiceDisplay* boxes_spice_display_new (BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port);
BoxesSpiceDisplay* boxes_spice_display_construct (GType object_type, BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port);
BoxesDisplay* boxes_display_construct (GType object_type);
void boxes_display_set_config (BoxesDisplay* self, BoxesBoxConfig* value);
BoxesSpiceDisplay* boxes_spice_display_new_with_uri (BoxesBoxConfig* config, const gchar* uri);
BoxesSpiceDisplay* boxes_spice_display_construct_with_uri (GType object_type, BoxesBoxConfig* config, const gchar* uri);
static GtkWidget* boxes_spice_display_real_get_display (BoxesDisplay* base, gint n);
static void ___lambda104_ (BoxesSpiceDisplay* self, gint status);
void boxes_display_set_mouse_grabbed (BoxesDisplay* self, gboolean value);
static void ____lambda104__spice_display_mouse_grab (SpiceDisplay* _sender, gint grabbed, gpointer self);
BoxesBoxConfig* boxes_display_get_config (BoxesDisplay* self);
static gboolean boxes_spice_display_has_usb_device_connected (BoxesSpiceDisplay* self);
static SpiceUsbDevice* _vala_SpiceUsbDevice_copy (SpiceUsbDevice* self);
static void _vala_SpiceUsbDevice_free (SpiceUsbDevice* self);
static gboolean boxes_spice_display_real_should_keep_alive (BoxesDisplay* base);
static void boxes_spice_display_real_set_enable_audio (BoxesDisplay* base, gboolean enable);
static void boxes_spice_display_real_set_enable_inputs (BoxesDisplay* base, GtkWidget* widget, gboolean enable);
static GdkPixbuf* boxes_spice_display_real_get_pixbuf (BoxesDisplay* base, gint n, GError** error);
static void boxes_spice_display_real_collect_logs (BoxesDisplay* base, GString* builder);
gchar* boxes_display_get_uri (BoxesDisplay* self);
static void boxes_spice_display_real_connect_it (BoxesDisplay* base, GError** error);
static void ___lambda105_ (BoxesSpiceDisplay* self, SpiceChannel* channel);
static void boxes_spice_display_main_event (BoxesSpiceDisplay* self, SpiceChannelEvent event);
static void _boxes_spice_display_main_event_spice_channel_channel_event (SpiceChannel* _sender, SpiceChannelEvent event, gpointer self);
static void ___lambda106_ (BoxesSpiceDisplay* self);
void boxes_display_set_can_grab_mouse (BoxesDisplay* self, gboolean value);
static void ____lambda106__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static Block54Data* block54_data_ref (Block54Data* _data54_);
static void block54_data_unref (void * _userdata_);
void boxes_display_access_start (BoxesDisplay* self);
static void ___lambda107_ (Block54Data* _data54_);
static void ____lambda107__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ____lambda105__spice_session_channel_new (SpiceSession* _sender, SpiceChannel* channel, gpointer self);
static void ___lambda108_ (BoxesSpiceDisplay* self, SpiceChannel* channel);
void boxes_display_access_finish (BoxesDisplay* self);
static void ____lambda108__spice_session_channel_destroy (SpiceSession* _sender, SpiceChannel* channel, gpointer self);
const gchar* boxes_display_get_password (BoxesDisplay* self);
static void boxes_spice_display_real_disconnect_it (BoxesDisplay* base);
void boxes_display_set_need_password (BoxesDisplay* self, gboolean value);
static GList* boxes_spice_display_real_get_properties (BoxesDisplay* base, BoxesPropertiesPage page, PropertyCreationFlag* flags);
BoxesProperty* boxes_iproperties_provider_add_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, GtkWidget* widget, GtkWidget* extra_widget);
static Block55Data* block55_data_ref (Block55Data* _data55_);
static void block55_data_unref (void * _userdata_);
static Block56Data* block56_data_ref (Block56Data* _data56_);
static void block56_data_unref (void * _userdata_);
static Block57Data* block57_data_ref (Block57Data* _data57_);
static void block57_data_unref (void * _userdata_);
static gint ___lambda0__gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self);
static gint ______lambda109_ (SpiceUsbDevice* a, SpiceUsbDevice* b);
static gint _______lambda109__gcompare_func (gconstpointer a, gconstpointer b);
static Block58Data* block58_data_ref (Block58Data* _data58_);
static void block58_data_unref (void * _userdata_);
static void _________lambda110_ (Block58Data* _data58_);
static void ___lambda111_ (Block58Data* _data58_, GObject* obj, GAsyncResult* res);
static void ____lambda111__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __________lambda110__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ______lambda112_ (Block56Data* _data56_, SpiceUsbDeviceManager* manager, SpiceUsbDevice* dev);
static void _______lambda112__spice_usb_device_manager_device_added (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, gpointer self);
static void ______lambda113_ (Block56Data* _data56_, SpiceUsbDeviceManager* manager, SpiceUsbDevice* dev);
static gboolean __lambda114_ (Block56Data* _data56_);
static gboolean ___lambda114__gsource_func (gpointer self);
static void _______lambda113__spice_usb_device_manager_device_removed (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, gpointer self);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
GByteArray* boxes_spice_display_get_ca_cert (BoxesSpiceDisplay* self);
void boxes_spice_display_set_ca_cert (BoxesSpiceDisplay* self, GByteArray* value);
void boxes_spice_display_set_resize_guest (BoxesSpiceDisplay* self, gboolean value);
static GObject * boxes_spice_display_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_spice_display____lambda115_ (BoxesSpiceDisplay* self, SpiceUsbDevice* dev, GError* err);
static void __boxes_spice_display____lambda115__spice_usb_device_manager_auto_connect_failed (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, GError* _error_, gpointer self);
static void _boxes_spice_display____lambda116_ (BoxesSpiceDisplay* self, SpiceUsbDevice* dev, GError* err);
static void __boxes_spice_display____lambda116__spice_usb_device_manager_device_error (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, GError* _error_, gpointer self);
static void _boxes_spice_display___lambda117_ (BoxesSpiceDisplay* self);
static void __boxes_spice_display___lambda117__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_spice_display_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_spice_display_finalize (GObject* obj);
const gchar* boxes_display_get_protocol (BoxesDisplay* self);
static void _vala_boxes_spice_display_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_spice_display_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
void spice_validate_uri (const gchar* uri_as_text, gint** port, gint** tls_port, GError** error);
static gint* _int_dup (gint* self);


static void _vala_BoxesBoxConfigSyncProperty_array_free (BoxesBoxConfigSyncProperty* array, gint array_length) {
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (array != NULL) {
#line 322 "spice-display.c"
		int i;
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			boxes_box_config_sync_property_destroy (&array[i]);
#line 328 "spice-display.c"
		}
	}
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_free (array);
#line 333 "spice-display.c"
}


static void boxes_spice_display_ui_state_changed (BoxesSpiceDisplay* self) {
	gboolean _tmp0_ = FALSE;
	BoxesApp* _tmp1_;
	BoxesUIState _tmp2_;
	BoxesUIState _tmp3_;
	gboolean _tmp7_;
#line 21 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = boxes_app_app;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp1_);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp3_ = _tmp2_;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp3_ == BOXES_UI_STATE_PROPERTIES) {
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp0_ = TRUE;
#line 355 "spice-display.c"
	} else {
		BoxesApp* _tmp4_;
		BoxesUIState _tmp5_;
		BoxesUIState _tmp6_;
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp4_ = boxes_app_app;
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp5_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp4_);
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp6_ = _tmp5_;
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp0_ = _tmp6_ == BOXES_UI_STATE_DISPLAY;
#line 368 "spice-display.c"
	}
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp7_ = _tmp0_;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp7_) {
#line 374 "spice-display.c"
		GtkWidget* _tmp8_ = NULL;
		SpiceDisplay* _tmp9_;
		SpiceDisplay* display;
		gboolean _tmp10_ = FALSE;
		BoxesApp* _tmp11_;
		BoxesUIState _tmp12_;
		BoxesUIState _tmp13_;
		SpiceDisplay* _tmp15_;
		gboolean _tmp16_;
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp8_ = boxes_display_get_display ((BoxesDisplay*) self, 0);
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp9_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp8_) : NULL;
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_tmp9_ == NULL) {
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (_tmp8_);
#line 392 "spice-display.c"
		}
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		display = _tmp9_;
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp11_ = boxes_app_app;
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp12_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp11_);
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp13_ = _tmp12_;
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_tmp13_ == BOXES_UI_STATE_DISPLAY) {
#line 404 "spice-display.c"
			gboolean _tmp14_;
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp14_ = self->priv->_resize_guest;
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp10_ = _tmp14_;
#line 410 "spice-display.c"
		} else {
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp10_ = FALSE;
#line 414 "spice-display.c"
		}
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp15_ = display;
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp16_ = _tmp10_;
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp15_, "resize-guest", _tmp16_, NULL);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (display);
#line 424 "spice-display.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return self ? g_object_ref (self) : NULL;
#line 432 "spice-display.c"
}


static void boxes_spice_display_main_cleanup (BoxesSpiceDisplay* self) {
	SpiceMainChannel* _tmp0_;
	SpiceMainChannel* _tmp1_;
	GObject* _tmp2_;
	GObject* o;
	GObject* _tmp3_;
	gulong _tmp4_;
	GObject* _tmp5_;
	gulong _tmp6_;
#line 75 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->main_channel;
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp0_ == NULL) {
#line 77 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		return;
#line 453 "spice-display.c"
	}
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = self->priv->main_channel;
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, G_TYPE_OBJECT) ? ((GObject*) _tmp1_) : NULL);
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	o = _tmp2_;
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp3_ = o;
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp4_ = self->priv->main_event_id;
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_signal_handler_disconnect (_tmp3_, _tmp4_);
#line 81 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->main_event_id = (gulong) 0;
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp5_ = o;
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp6_ = self->priv->main_mouse_mode_id;
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_signal_handler_disconnect (_tmp5_, _tmp6_);
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->main_mouse_mode_id = (gulong) 0;
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->main_channel);
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->main_channel = NULL;
#line 75 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (o);
#line 483 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_construct (GType object_type, BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port) {
	BoxesSpiceDisplay * self = NULL;
	gint _tmp0_;
	gint _tmp1_;
	BoxesBoxConfig* _tmp2_;
	SpiceSession* _tmp3_;
	const gchar* _tmp4_;
	gint _tmp5_;
	gint _tmp10_;
	SpiceSession* _tmp15_;
	const gchar* _tmp16_ = NULL;
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (config != NULL, NULL);
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (host != NULL, NULL);
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = port;
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = tls_port;
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail ((_tmp0_ != 0) || (_tmp1_ != 0), NULL);
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) boxes_display_construct (object_type);
#line 93 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = config;
#line 93 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	boxes_display_set_config ((BoxesDisplay*) self, _tmp2_);
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp3_ = self->priv->session;
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp4_ = host;
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp3_, "host", _tmp4_, NULL);
#line 96 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp5_ = port;
#line 96 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp5_ != 0) {
#line 524 "spice-display.c"
		SpiceSession* _tmp6_;
		gint _tmp7_;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_;
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp6_ = self->priv->session;
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp7_ = port;
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp8_ = g_strdup_printf ("%i", _tmp7_);
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp9_ = _tmp8_;
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp6_, "port", _tmp9_, NULL);
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp9_);
#line 541 "spice-display.c"
	}
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp10_ = tls_port;
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp10_ != 0) {
#line 547 "spice-display.c"
		SpiceSession* _tmp11_;
		gint _tmp12_;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_;
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp11_ = self->priv->session;
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp12_ = tls_port;
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp13_ = g_strdup_printf ("%i", _tmp12_);
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp14_ = _tmp13_;
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp11_, "tls-port", _tmp14_, NULL);
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp14_);
#line 564 "spice-display.c"
	}
#line 105 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp15_ = self->priv->session;
#line 105 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp16_ = g_getenv ("BOXES_SPICE_HOST_SUBJECT");
#line 105 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp15_, "cert-subject", _tmp16_, NULL);
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return self;
#line 574 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_new (BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port) {
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return boxes_spice_display_construct (BOXES_TYPE_SPICE_DISPLAY, config, host, port, tls_port);
#line 581 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_construct_with_uri (GType object_type, BoxesBoxConfig* config, const gchar* uri) {
	BoxesSpiceDisplay * self = NULL;
	BoxesBoxConfig* _tmp0_;
	SpiceSession* _tmp1_;
	const gchar* _tmp2_;
#line 108 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (config != NULL, NULL);
#line 108 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (uri != NULL, NULL);
#line 108 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) boxes_display_construct (object_type);
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = config;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	boxes_display_set_config ((BoxesDisplay*) self, _tmp0_);
#line 111 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = self->priv->session;
#line 111 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = uri;
#line 111 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp1_, "uri", _tmp2_, NULL);
#line 108 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return self;
#line 608 "spice-display.c"
}


BoxesSpiceDisplay* boxes_spice_display_new_with_uri (BoxesBoxConfig* config, const gchar* uri) {
#line 108 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return boxes_spice_display_construct_with_uri (BOXES_TYPE_SPICE_DISPLAY, config, uri);
#line 615 "spice-display.c"
}


static void ___lambda104_ (BoxesSpiceDisplay* self, gint status) {
	gint _tmp0_;
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = status;
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	boxes_display_set_mouse_grabbed ((BoxesDisplay*) self, _tmp0_ != 0);
#line 625 "spice-display.c"
}


static void ____lambda104__spice_display_mouse_grab (SpiceDisplay* _sender, gint grabbed, gpointer self) {
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	___lambda104_ (self, grabbed);
#line 632 "spice-display.c"
}


static GtkWidget* boxes_spice_display_real_get_display (BoxesDisplay* base, gint n) {
	BoxesSpiceDisplay * self;
	GtkWidget* result = NULL;
	GHashTable* _tmp0_;
	gint _tmp1_;
	gconstpointer _tmp2_ = NULL;
	GtkWidget* _tmp3_;
	SpiceDisplay* _tmp4_;
	SpiceDisplay* display;
	SpiceDisplay* _tmp5_;
#line 114 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = ((BoxesDisplay*) self)->displays;
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = n;
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = g_hash_table_lookup (_tmp0_, (gpointer) ((gintptr) _tmp1_));
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp3_ = (GtkWidget*) _tmp2_;
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp3_) : NULL);
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	display = _tmp4_;
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp5_ = display;
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp5_ == NULL) {
#line 664 "spice-display.c"
		SpiceSession* _tmp6_;
		gint _tmp7_;
		SpiceDisplay* _tmp8_;
		SpiceDisplay* _tmp9_;
		BoxesBoxConfig* _tmp10_;
		BoxesBoxConfig* _tmp11_;
		BoxesBoxConfigSyncProperty* _tmp12_;
		gint _tmp12__length1;
		SpiceDisplay* _tmp13_;
		SpiceDisplay* _tmp14_;
		GObjectClass* _tmp15_ = NULL;
		GParamSpec* _tmp16_ = NULL;
		GHashTable* _tmp18_;
		gint _tmp19_;
		SpiceDisplay* _tmp20_;
		GtkWidget* _tmp21_;
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp6_ = self->priv->session;
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp7_ = n;
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp8_ = spice_display_new (_tmp6_, _tmp7_);
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_object_ref_sink (_tmp8_);
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (display);
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		display = _tmp8_;
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp9_ = display;
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_signal_connect_object (_tmp9_, "mouse-grab", (GCallback) ____lambda104__spice_display_mouse_grab, self, 0);
#line 123 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp10_ = boxes_display_get_config ((BoxesDisplay*) self);
#line 123 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp11_ = _tmp10_;
#line 123 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp12_ = self->priv->display_sync_properties;
#line 123 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp12__length1 = self->priv->display_sync_properties_length1;
#line 123 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		boxes_box_config_sync_properties (_tmp11_, (GObject*) self, _tmp12_, _tmp12__length1);
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp13_ = display;
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_object_set (_tmp13_, "scaling", TRUE, NULL);
#line 125 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp14_ = display;
#line 125 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp15_ = G_OBJECT_GET_CLASS ((GObject*) _tmp14_);
#line 125 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp16_ = g_object_class_find_property (_tmp15_, "only-downscale");
#line 125 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_tmp16_ != NULL) {
#line 719 "spice-display.c"
			SpiceDisplay* _tmp17_;
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp17_ = display;
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			g_object_set ((GObject*) _tmp17_, "only-downscale", TRUE, NULL);
#line 725 "spice-display.c"
		}
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp18_ = ((BoxesDisplay*) self)->displays;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp19_ = n;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp20_ = display;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp21_ = _g_object_ref0 ((GtkWidget*) _tmp20_);
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_hash_table_replace (_tmp18_, (gpointer) ((gintptr) _tmp19_), _tmp21_);
#line 737 "spice-display.c"
	}
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	result = (GtkWidget*) display;
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return result;
#line 743 "spice-display.c"
}


static gint g_ptr_array_get_length (GPtrArray* self) {
	gint result;
	guint _tmp0_;
#line 4095 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 4095 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp0_ = self->len;
#line 4095 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	result = (gint) _tmp0_;
#line 4095 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	return result;
#line 758 "spice-display.c"
}


static void g_ptr_array_set_length (GPtrArray* self, gint value) {
	gint _tmp0_;
#line 4096 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4096 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp0_ = value;
#line 4096 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	g_ptr_array_set_size (self, _tmp0_);
#line 770 "spice-display.c"
}


static SpiceUsbDevice* _vala_SpiceUsbDevice_copy (SpiceUsbDevice* self) {
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return g_boxed_copy (spice_usb_device_get_type (), self);
#line 777 "spice-display.c"
}


static gpointer __vala_SpiceUsbDevice_copy0 (gpointer self) {
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return self ? _vala_SpiceUsbDevice_copy (self) : NULL;
#line 784 "spice-display.c"
}


static void _vala_SpiceUsbDevice_free (SpiceUsbDevice* self) {
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_boxed_free (spice_usb_device_get_type (), self);
#line 791 "spice-display.c"
}


static gboolean boxes_spice_display_has_usb_device_connected (BoxesSpiceDisplay* self) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 134 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 800 "spice-display.c"
	{
		SpiceSession* _tmp0_;
		SpiceUsbDeviceManager* _tmp1_ = NULL;
		SpiceUsbDeviceManager* _tmp2_;
		SpiceUsbDeviceManager* manager;
		SpiceUsbDeviceManager* _tmp3_;
		GPtrArray* _tmp4_ = NULL;
		GPtrArray* devs;
#line 136 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp0_ = self->priv->session;
#line 136 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp1_ = spice_usb_device_manager_get (_tmp0_, &_inner_error_);
#line 136 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp2_ = _g_object_ref0 (_tmp1_);
#line 136 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		manager = _tmp2_;
#line 136 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_inner_error_ != NULL) {
#line 819 "spice-display.c"
			goto __catch65_g_error;
		}
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp3_ = manager;
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp4_ = spice_usb_device_manager_get_devices (_tmp3_);
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		devs = _tmp4_;
#line 828 "spice-display.c"
		{
			gint i;
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			i = 0;
#line 833 "spice-display.c"
			{
				gboolean _tmp5_;
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_tmp5_ = TRUE;
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				while (TRUE) {
#line 840 "spice-display.c"
					gboolean _tmp6_;
					gint _tmp8_;
					GPtrArray* _tmp9_;
					gint _tmp10_;
					gint _tmp11_;
					GPtrArray* _tmp12_;
					gint _tmp13_;
					gconstpointer _tmp14_ = NULL;
					SpiceUsbDevice* _tmp15_;
					SpiceUsbDevice* dev;
					SpiceUsbDeviceManager* _tmp16_;
					SpiceUsbDevice* _tmp17_;
					gboolean _tmp18_ = FALSE;
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp6_ = _tmp5_;
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					if (!_tmp6_) {
#line 858 "spice-display.c"
						gint _tmp7_;
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_tmp7_ = i;
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						i = _tmp7_ + 1;
#line 864 "spice-display.c"
					}
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp5_ = FALSE;
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp8_ = i;
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp9_ = devs;
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp10_ = g_ptr_array_get_length (_tmp9_);
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp11_ = _tmp10_;
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					if (!(_tmp8_ < _tmp11_)) {
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						break;
#line 880 "spice-display.c"
					}
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp12_ = devs;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp13_ = i;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp14_ = g_ptr_array_index (_tmp12_, (guint) _tmp13_);
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp15_ = __vala_SpiceUsbDevice_copy0 ((SpiceUsbDevice*) _tmp14_);
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					dev = _tmp15_;
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp16_ = manager;
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp17_ = dev;
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp18_ = spice_usb_device_manager_is_device_connected (_tmp16_, _tmp17_);
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					if (_tmp18_) {
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						result = TRUE;
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						__vala_SpiceUsbDevice_free0 (dev);
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_g_ptr_array_unref0 (devs);
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_g_object_unref0 (manager);
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						return result;
#line 910 "spice-display.c"
					}
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					__vala_SpiceUsbDevice_free0 (dev);
#line 914 "spice-display.c"
				}
			}
		}
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_ptr_array_unref0 (devs);
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (manager);
#line 922 "spice-display.c"
	}
	goto __finally65;
	__catch65_g_error:
	{
		GError* _error_ = NULL;
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_error_ = _inner_error_;
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (_error_);
#line 934 "spice-display.c"
	}
	__finally65:
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_inner_error_ != NULL) {
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		return FALSE;
#line 945 "spice-display.c"
	}
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	result = FALSE;
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return result;
#line 951 "spice-display.c"
}


static gboolean boxes_spice_display_real_should_keep_alive (BoxesDisplay* base) {
	BoxesSpiceDisplay * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
	gboolean _tmp3_;
#line 148 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = self->priv->closed;
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (!_tmp1_) {
#line 967 "spice-display.c"
		gboolean _tmp2_ = FALSE;
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp2_ = boxes_spice_display_has_usb_device_connected (self);
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp0_ = _tmp2_;
#line 973 "spice-display.c"
	} else {
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp0_ = FALSE;
#line 977 "spice-display.c"
	}
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp3_ = _tmp0_;
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	result = _tmp3_;
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return result;
#line 985 "spice-display.c"
}


static void boxes_spice_display_real_set_enable_audio (BoxesDisplay* base, gboolean enable) {
	BoxesSpiceDisplay * self;
	SpiceSession* _tmp0_;
	gboolean _tmp1_;
#line 152 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = enable;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp0_, "enable-audio", _tmp1_, NULL);
#line 1001 "spice-display.c"
}


static void boxes_spice_display_real_set_enable_inputs (BoxesDisplay* base, GtkWidget* widget, gboolean enable) {
	BoxesSpiceDisplay * self;
	GtkWidget* _tmp0_;
	gboolean _tmp1_;
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (widget != NULL);
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = widget;
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = enable;
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_set (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp0_) : NULL, "disable-inputs", !_tmp1_, NULL);
#line 1019 "spice-display.c"
}


static GdkPixbuf* boxes_spice_display_real_get_pixbuf (BoxesDisplay* base, gint n, GError** error) {
	BoxesSpiceDisplay * self;
	GdkPixbuf* result = NULL;
	gint _tmp0_;
	GtkWidget* _tmp1_ = NULL;
	SpiceDisplay* _tmp2_;
	SpiceDisplay* display;
	SpiceDisplay* _tmp3_;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_;
	SpiceDisplay* _tmp6_;
	GdkPixbuf* _tmp7_ = NULL;
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = n;
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = boxes_display_get_display ((BoxesDisplay*) self, _tmp0_);
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp1_) : NULL;
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp2_ == NULL) {
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_tmp1_);
#line 1047 "spice-display.c"
	}
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	display = _tmp2_;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp3_ = display;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp3_, "ready", &_tmp4_, NULL);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp5_ = _tmp4_;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (!_tmp5_) {
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		result = NULL;
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (display);
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		return result;
#line 1065 "spice-display.c"
	}
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp6_ = display;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp7_ = spice_display_get_pixbuf (_tmp6_);
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	result = _tmp7_;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (display);
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return result;
#line 1077 "spice-display.c"
}


static void boxes_spice_display_real_collect_logs (BoxesDisplay* base, GString* builder) {
	BoxesSpiceDisplay * self;
	GString* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_ = NULL;
	gboolean _tmp5_;
	GString* _tmp6_;
	const gchar* _tmp7_;
	SpiceGtkSession* _tmp8_;
	SpiceMainChannel* _tmp21_;
	GError * _inner_error_ = NULL;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (builder != NULL);
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = builder;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = boxes_display_get_uri ((BoxesDisplay*) self);
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp3_ = _tmp2_;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_string_append_printf (_tmp0_, "URI: %s\n", _tmp3_);
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp3_);
#line 171 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp5_ = self->priv->_resize_guest;
#line 171 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp5_) {
#line 171 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp4_ = "yes";
#line 1116 "spice-display.c"
	} else {
#line 171 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp4_ = "no";
#line 1120 "spice-display.c"
	}
#line 171 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp6_ = builder;
#line 171 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp7_ = _tmp4_;
#line 171 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_string_append_printf (_tmp6_, "Auto resize guest: %s\n", _tmp7_);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp8_ = self->priv->gtk_session;
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp8_ != NULL) {
#line 1132 "spice-display.c"
		const gchar* _tmp9_ = NULL;
		SpiceGtkSession* _tmp10_;
		gboolean _tmp11_ = FALSE;
		gboolean _tmp12_;
		GString* _tmp13_;
		const gchar* _tmp14_;
		const gchar* _tmp15_ = NULL;
		SpiceGtkSession* _tmp16_;
		gboolean _tmp17_ = FALSE;
		gboolean _tmp18_;
		GString* _tmp19_;
		const gchar* _tmp20_;
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp10_ = self->priv->gtk_session;
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp10_, "auto-usbredir", &_tmp11_, NULL);
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp12_ = _tmp11_;
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_tmp12_) {
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp9_ = "yes";
#line 1155 "spice-display.c"
		} else {
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp9_ = "no";
#line 1159 "spice-display.c"
		}
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp13_ = builder;
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp14_ = _tmp9_;
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp13_, "Auto redirect USB: %s\n", _tmp14_);
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp16_ = self->priv->gtk_session;
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp16_, "auto-clipboard", &_tmp17_, NULL);
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp18_ = _tmp17_;
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_tmp18_) {
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp15_ = "yes";
#line 1177 "spice-display.c"
		} else {
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp15_ = "no";
#line 1181 "spice-display.c"
		}
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp19_ = builder;
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp20_ = _tmp15_;
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp19_, "Auto clipboard sync: %s\n", _tmp20_);
#line 1189 "spice-display.c"
	}
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp21_ = self->priv->main_channel;
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp21_ != NULL) {
#line 1195 "spice-display.c"
		GString* _tmp22_;
		const gchar* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
		SpiceMainChannel* _tmp25_;
		gint _tmp26_ = 0;
		gint _tmp27_;
		GString* _tmp28_;
		const gchar* _tmp29_;
		const gchar* _tmp30_ = NULL;
		SpiceMainChannel* _tmp31_;
		gboolean _tmp32_ = FALSE;
		gboolean _tmp33_;
		GString* _tmp34_;
		const gchar* _tmp35_;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp22_ = builder;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp23_ = spice_util_get_version_string ();
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp22_, "Spice-gtk version %s\n", _tmp23_);
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp25_ = self->priv->main_channel;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp25_, "mouse-mode", &_tmp26_, NULL);
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp27_ = _tmp26_;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_tmp27_ == 1) {
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp24_ = "server";
#line 1226 "spice-display.c"
		} else {
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp24_ = "client";
#line 1230 "spice-display.c"
		}
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp28_ = builder;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp29_ = _tmp24_;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp28_, "Mouse mode: %s\n", _tmp29_);
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp31_ = self->priv->main_channel;
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp31_, "agent-connected", &_tmp32_, NULL);
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp33_ = _tmp32_;
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_tmp33_) {
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp30_ = "connected";
#line 1248 "spice-display.c"
		} else {
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp30_ = "disconnected";
#line 1252 "spice-display.c"
		}
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp34_ = builder;
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp35_ = _tmp30_;
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_string_append_printf (_tmp34_, "Agent: %s\n", _tmp35_);
#line 1260 "spice-display.c"
	}
	{
		SpiceSession* _tmp36_;
		SpiceUsbDeviceManager* _tmp37_ = NULL;
		SpiceUsbDeviceManager* _tmp38_;
		SpiceUsbDeviceManager* manager;
		SpiceUsbDeviceManager* _tmp39_;
		GPtrArray* _tmp40_ = NULL;
		GPtrArray* devs;
#line 183 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp36_ = self->priv->session;
#line 183 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp37_ = spice_usb_device_manager_get (_tmp36_, &_inner_error_);
#line 183 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp38_ = _g_object_ref0 (_tmp37_);
#line 183 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		manager = _tmp38_;
#line 183 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_inner_error_ != NULL) {
#line 1280 "spice-display.c"
			goto __catch66_g_error;
		}
#line 184 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp39_ = manager;
#line 184 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp40_ = spice_usb_device_manager_get_devices (_tmp39_);
#line 184 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		devs = _tmp40_;
#line 1289 "spice-display.c"
		{
			gint i;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			i = 0;
#line 1294 "spice-display.c"
			{
				gboolean _tmp41_;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_tmp41_ = TRUE;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				while (TRUE) {
#line 1301 "spice-display.c"
					gboolean _tmp42_;
					gint _tmp44_;
					GPtrArray* _tmp45_;
					gint _tmp46_;
					gint _tmp47_;
					GPtrArray* _tmp48_;
					gint _tmp49_;
					gconstpointer _tmp50_ = NULL;
					SpiceUsbDevice* _tmp51_;
					SpiceUsbDevice* dev;
					SpiceUsbDeviceManager* _tmp52_;
					SpiceUsbDevice* _tmp53_;
					gboolean _tmp54_ = FALSE;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp42_ = _tmp41_;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					if (!_tmp42_) {
#line 1319 "spice-display.c"
						gint _tmp43_;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_tmp43_ = i;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						i = _tmp43_ + 1;
#line 1325 "spice-display.c"
					}
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp41_ = FALSE;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp44_ = i;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp45_ = devs;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp46_ = g_ptr_array_get_length (_tmp45_);
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp47_ = _tmp46_;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					if (!(_tmp44_ < _tmp47_)) {
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						break;
#line 1341 "spice-display.c"
					}
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp48_ = devs;
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp49_ = i;
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp50_ = g_ptr_array_index (_tmp48_, (guint) _tmp49_);
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp51_ = __vala_SpiceUsbDevice_copy0 ((SpiceUsbDevice*) _tmp50_);
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					dev = _tmp51_;
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp52_ = manager;
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp53_ = dev;
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_tmp54_ = spice_usb_device_manager_is_device_connected (_tmp52_, _tmp53_);
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					if (_tmp54_) {
#line 1361 "spice-display.c"
						GString* _tmp55_;
						SpiceUsbDevice* _tmp56_;
						gchar* _tmp57_ = NULL;
						gchar* _tmp58_;
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_tmp55_ = builder;
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_tmp56_ = dev;
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_tmp57_ = spice_usb_device_get_description (_tmp56_, "%s %s %s at %d-%d");
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_tmp58_ = _tmp57_;
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						g_string_append_printf (_tmp55_, "USB device redirected: %s\n", _tmp58_);
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_g_free0 (_tmp58_);
#line 1378 "spice-display.c"
					}
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					__vala_SpiceUsbDevice_free0 (dev);
#line 1382 "spice-display.c"
				}
			}
		}
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_ptr_array_unref0 (devs);
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (manager);
#line 1390 "spice-display.c"
	}
	goto __finally66;
	__catch66_g_error:
	{
		GError* _error_ = NULL;
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_error_ = _inner_error_;
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (_error_);
#line 1402 "spice-display.c"
	}
	__finally66:
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_inner_error_ != NULL) {
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		return;
#line 1413 "spice-display.c"
	}
}


static void _boxes_spice_display_main_event_spice_channel_channel_event (SpiceChannel* _sender, SpiceChannelEvent event, gpointer self) {
#line 209 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_main_event (self, event);
#line 1421 "spice-display.c"
}


static void ___lambda106_ (BoxesSpiceDisplay* self) {
	SpiceMainChannel* _tmp0_;
	gint _tmp1_ = 0;
	gint _tmp2_;
#line 211 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->main_channel;
#line 211 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp0_, "mouse-mode", &_tmp1_, NULL);
#line 211 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 211 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	boxes_display_set_can_grab_mouse ((BoxesDisplay*) self, _tmp2_ != 2);
#line 1437 "spice-display.c"
}


static void ____lambda106__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 210 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	___lambda106_ (self);
#line 1444 "spice-display.c"
}


static Block54Data* block54_data_ref (Block54Data* _data54_) {
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data54_->_ref_count_);
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return _data54_;
#line 1453 "spice-display.c"
}


static void block54_data_unref (void * _userdata_) {
	Block54Data* _data54_;
	_data54_ = (Block54Data*) _userdata_;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data54_->_ref_count_)) {
#line 1462 "spice-display.c"
		BoxesSpiceDisplay * self;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		self = _data54_->self;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data54_->display);
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (self);
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block54Data, _data54_);
#line 1472 "spice-display.c"
	}
}


static void ___lambda107_ (Block54Data* _data54_) {
	BoxesSpiceDisplay * self;
	SpiceDisplay* _tmp0_;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_;
#line 222 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = _data54_->self;
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data54_->display;
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp0_, "ready", &_tmp1_, NULL);
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp2_) {
#line 1492 "spice-display.c"
		SpiceDisplay* _tmp3_;
		gint _tmp4_ = 0;
		gint _tmp5_;
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp3_ = _data54_->display;
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp3_, "channel-id", &_tmp4_, NULL);
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp5_ = _tmp4_;
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_signal_emit_by_name ((BoxesDisplay*) self, "show", _tmp5_);
#line 1504 "spice-display.c"
	} else {
		SpiceDisplay* _tmp6_;
		gint _tmp7_ = 0;
		gint _tmp8_;
#line 226 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp6_ = _data54_->display;
#line 226 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp6_, "channel-id", &_tmp7_, NULL);
#line 226 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp8_ = _tmp7_;
#line 226 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_signal_emit_by_name ((BoxesDisplay*) self, "hide", _tmp8_);
#line 1517 "spice-display.c"
	}
}


static void ____lambda107__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 222 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	___lambda107_ (self);
#line 1525 "spice-display.c"
}


static void ___lambda105_ (BoxesSpiceDisplay* self, SpiceChannel* channel) {
	SpiceChannel* _tmp0_;
	gint _tmp1_ = 0;
	gint _tmp2_;
	gint id;
	SpiceChannel* _tmp3_;
	SpiceChannel* _tmp13_;
#line 204 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (channel != NULL);
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = channel;
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp0_, "channel-id", &_tmp1_, NULL);
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	id = _tmp2_;
#line 207 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp3_ = channel;
#line 207 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, spice_main_channel_get_type ())) {
#line 1550 "spice-display.c"
		SpiceChannel* _tmp4_;
		SpiceMainChannel* _tmp5_;
		SpiceMainChannel* _tmp6_;
		gulong _tmp7_ = 0UL;
		SpiceMainChannel* _tmp8_;
		gulong _tmp9_ = 0UL;
		SpiceMainChannel* _tmp10_;
		gint _tmp11_ = 0;
		gint _tmp12_;
#line 208 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp4_ = channel;
#line 208 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, spice_main_channel_get_type ()) ? ((SpiceMainChannel*) _tmp4_) : NULL);
#line 208 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (self->priv->main_channel);
#line 208 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		self->priv->main_channel = _tmp5_;
#line 209 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp6_ = self->priv->main_channel;
#line 209 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp7_ = g_signal_connect_object ((SpiceChannel*) _tmp6_, "channel-event", (GCallback) _boxes_spice_display_main_event_spice_channel_channel_event, self, 0);
#line 209 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		self->priv->main_event_id = _tmp7_;
#line 210 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp8_ = self->priv->main_channel;
#line 210 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp9_ = g_signal_connect_object ((GObject*) _tmp8_, "notify::mouse-mode", (GCallback) ____lambda106__g_object_notify, self, 0);
#line 210 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		self->priv->main_mouse_mode_id = _tmp9_;
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp10_ = self->priv->main_channel;
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_object_get (_tmp10_, "mouse-mode", &_tmp11_, NULL);
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp12_ = _tmp11_;
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		boxes_display_set_can_grab_mouse ((BoxesDisplay*) self, _tmp12_ != 2);
#line 1588 "spice-display.c"
	}
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp13_ = channel;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, spice_display_channel_get_type ())) {
#line 1594 "spice-display.c"
		Block54Data* _data54_;
		gint _tmp14_;
		gint _tmp15_;
		GtkWidget* _tmp16_ = NULL;
		SpiceDisplay* _tmp17_;
		SpiceDisplay* _tmp18_;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_data54_ = g_slice_new0 (Block54Data);
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_data54_->_ref_count_ = 1;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_data54_->self = g_object_ref (self);
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp14_ = id;
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_tmp14_ != 0) {
#line 218 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			block54_data_unref (_data54_);
#line 218 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_data54_ = NULL;
#line 218 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			return;
#line 1617 "spice-display.c"
		}
#line 220 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		boxes_display_access_start ((BoxesDisplay*) self);
#line 221 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp15_ = id;
#line 221 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp16_ = boxes_display_get_display ((BoxesDisplay*) self, _tmp15_);
#line 221 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp17_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, spice_display_get_type ()) ? ((SpiceDisplay*) _tmp16_) : NULL;
#line 221 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_tmp17_ == NULL) {
#line 221 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (_tmp16_);
#line 1631 "spice-display.c"
		}
#line 221 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_data54_->display = _tmp17_;
#line 222 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp18_ = _data54_->display;
#line 222 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_signal_connect_data ((GObject*) _tmp18_, "notify::ready", (GCallback) ____lambda107__g_object_notify, block54_data_ref (_data54_), (GClosureNotify) block54_data_unref, 0);
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		block54_data_unref (_data54_);
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_data54_ = NULL;
#line 1643 "spice-display.c"
	}
}


static void ____lambda105__spice_session_channel_new (SpiceSession* _sender, SpiceChannel* channel, gpointer self) {
#line 204 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	___lambda105_ (self, channel);
#line 1651 "spice-display.c"
}


static void ___lambda108_ (BoxesSpiceDisplay* self, SpiceChannel* channel) {
	SpiceChannel* _tmp0_;
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (channel != NULL);
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = channel;
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, spice_display_channel_get_type ())) {
#line 1663 "spice-display.c"
		SpiceChannel* _tmp1_;
		SpiceDisplayChannel* _tmp2_;
		SpiceDisplayChannel* display;
		SpiceDisplayChannel* _tmp3_;
		gint _tmp4_ = 0;
		gint _tmp5_;
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp1_ = channel;
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, spice_display_channel_get_type ()) ? ((SpiceDisplayChannel*) _tmp1_) : NULL);
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		display = _tmp2_;
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp3_ = display;
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_object_get ((SpiceChannel*) _tmp3_, "channel-id", &_tmp4_, NULL);
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp5_ = _tmp4_;
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_signal_emit_by_name ((BoxesDisplay*) self, "hide", _tmp5_);
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		boxes_display_access_finish ((BoxesDisplay*) self);
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (display);
#line 1688 "spice-display.c"
	}
}


static void ____lambda108__spice_session_channel_destroy (SpiceSession* _sender, SpiceChannel* channel, gpointer self) {
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	___lambda108_ (self, channel);
#line 1696 "spice-display.c"
}


static void boxes_spice_display_real_connect_it (BoxesDisplay* base, GError** error) {
	BoxesSpiceDisplay * self;
	gboolean _tmp0_;
	gulong _tmp1_;
	gulong _tmp4_;
	SpiceSession* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	SpiceSession* _tmp10_;
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 196 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->connected;
#line 196 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp0_) {
#line 197 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		return;
#line 1717 "spice-display.c"
	}
#line 198 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->connected = TRUE;
#line 200 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_main_cleanup (self);
#line 203 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = self->priv->channel_new_id;
#line 203 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp1_ == ((gulong) 0)) {
#line 1727 "spice-display.c"
		SpiceSession* _tmp2_;
		gulong _tmp3_ = 0UL;
#line 204 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp2_ = self->priv->session;
#line 204 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp3_ = g_signal_connect_object (_tmp2_, "channel-new", (GCallback) ____lambda105__spice_session_channel_new, self, 0);
#line 204 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		self->priv->channel_new_id = _tmp3_;
#line 1736 "spice-display.c"
	}
#line 231 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp4_ = self->priv->channel_destroy_id;
#line 231 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp4_ == ((gulong) 0)) {
#line 1742 "spice-display.c"
		SpiceSession* _tmp5_;
		gulong _tmp6_ = 0UL;
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp5_ = self->priv->session;
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp6_ = g_signal_connect_object (_tmp5_, "channel-destroy", (GCallback) ____lambda108__spice_session_channel_destroy, self, 0);
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		self->priv->channel_destroy_id = _tmp6_;
#line 1751 "spice-display.c"
	}
#line 240 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp7_ = self->priv->session;
#line 240 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp8_ = boxes_display_get_password ((BoxesDisplay*) self);
#line 240 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp9_ = _tmp8_;
#line 240 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp7_, "password", _tmp9_, NULL);
#line 241 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp10_ = self->priv->session;
#line 241 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	spice_session_connect (_tmp10_);
#line 1765 "spice-display.c"
}


static void boxes_spice_display_real_disconnect_it (BoxesDisplay* base) {
	BoxesSpiceDisplay * self;
	SpiceSession* _tmp0_;
#line 244 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 245 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 245 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	spice_session_disconnect (_tmp0_);
#line 1778 "spice-display.c"
}


static void boxes_spice_display_main_event (BoxesSpiceDisplay* self, SpiceChannelEvent event) {
	SpiceChannelEvent _tmp0_;
#line 248 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = event;
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	switch (_tmp0_) {
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_CLOSED:
#line 1792 "spice-display.c"
		{
#line 251 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			self->priv->closed = TRUE;
#line 252 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			g_signal_emit_by_name ((BoxesDisplay*) self, "disconnected");
#line 253 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			break;
#line 1800 "spice-display.c"
		}
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		case SPICE_CHANNEL_ERROR_AUTH:
#line 1804 "spice-display.c"
		{
#line 256 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			boxes_display_set_need_password ((BoxesDisplay*) self, TRUE);
#line 257 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			break;
#line 1810 "spice-display.c"
		}
		default:
		{
#line 260 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			break;
#line 1816 "spice-display.c"
		}
	}
}


static Block55Data* block55_data_ref (Block55Data* _data55_) {
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data55_->_ref_count_);
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return _data55_;
#line 1827 "spice-display.c"
}


static void block55_data_unref (void * _userdata_) {
	Block55Data* _data55_;
	_data55_ = (Block55Data*) _userdata_;
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data55_->_ref_count_)) {
#line 1836 "spice-display.c"
		BoxesSpiceDisplay * self;
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		self = _data55_->self;
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data55_->usb_property);
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (self);
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block55Data, _data55_);
#line 1846 "spice-display.c"
	}
}


static Block56Data* block56_data_ref (Block56Data* _data56_) {
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data56_->_ref_count_);
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return _data56_;
#line 1856 "spice-display.c"
}


static void block56_data_unref (void * _userdata_) {
	Block56Data* _data56_;
	_data56_ = (Block56Data*) _userdata_;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data56_->_ref_count_)) {
#line 1865 "spice-display.c"
		BoxesSpiceDisplay * self;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		self = _data56_->_data55_->self;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data56_->manager);
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		block55_data_unref (_data56_->_data55_);
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_data56_->_data55_ = NULL;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block56Data, _data56_);
#line 1877 "spice-display.c"
	}
}


static Block57Data* block57_data_ref (Block57Data* _data57_) {
#line 4079 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	g_atomic_int_inc (&_data57_->_ref_count_);
#line 4079 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	return _data57_;
#line 1887 "spice-display.c"
}


static void block57_data_unref (void * _userdata_) {
	Block57Data* _data57_;
	_data57_ = (Block57Data*) _userdata_;
#line 4079 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	if (g_atomic_int_dec_and_test (&_data57_->_ref_count_)) {
#line 1896 "spice-display.c"
		GPtrArray * self;
#line 4079 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
		self = _data57_->self;
#line 4079 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
		_g_ptr_array_unref0 (self);
#line 4079 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
		g_slice_free (Block57Data, _data57_);
#line 1904 "spice-display.c"
	}
}


static gint __lambda0_ (Block57Data* _data57_, gconstpointer** a, gconstpointer** b) {
	GPtrArray * self;
	gint result = 0;
	GCompareFunc _tmp0_;
	gconstpointer** _tmp1_;
	gconstpointer** _tmp2_;
	gint _tmp3_ = 0;
#line 4080 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	self = _data57_->self;
#line 4081 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp0_ = _data57_->compare_func;
#line 4081 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp1_ = a;
#line 4081 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp2_ = b;
#line 4081 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp3_ = _tmp0_ ((gconstpointer**) (*_tmp1_), (gconstpointer**) (*_tmp2_));
#line 4081 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	result = _tmp3_;
#line 4081 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	return result;
#line 1930 "spice-display.c"
}


static gint ___lambda0__gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gint result;
	result = __lambda0_ (self, a, b);
#line 4080 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	return result;
#line 1939 "spice-display.c"
}


static void vala_g_ptr_array_sort (GPtrArray* self, GCompareFunc compare_func) {
	Block57Data* _data57_;
	GCompareFunc _tmp0_;
#line 4079 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4079 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	_data57_ = g_slice_new0 (Block57Data);
#line 4079 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	_data57_->_ref_count_ = 1;
#line 4079 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	_data57_->self = g_ptr_array_ref (self);
#line 4079 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	_tmp0_ = compare_func;
#line 4079 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	_data57_->compare_func = _tmp0_;
#line 4080 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	g_ptr_array_sort_with_data (self, ___lambda0__gcompare_data_func, _data57_);
#line 4079 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	block57_data_unref (_data57_);
#line 4079 "/home/teuf/jhbuild-boxes/opt/share/vala-0.20/vapi/glib-2.0.vapi"
	_data57_ = NULL;
#line 1964 "spice-display.c"
}


static gint ______lambda109_ (SpiceUsbDevice* a, SpiceUsbDevice* b) {
	gint result = 0;
	SpiceUsbDevice* _tmp0_;
	gchar* _tmp1_ = NULL;
	gchar* str_a;
	SpiceUsbDevice* _tmp2_;
	gchar* _tmp3_ = NULL;
	gchar* str_b;
	GCompareFunc _tmp4_;
	gint _tmp5_ = 0;
#line 295 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (a != NULL, 0);
#line 295 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (b != NULL, 0);
#line 296 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = a;
#line 296 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = spice_usb_device_get_description (_tmp0_, "    %1$s %2$s");
#line 296 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	str_a = _tmp1_;
#line 297 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = b;
#line 297 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp3_ = spice_usb_device_get_description (_tmp2_, "    %1$s %2$s");
#line 297 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	str_b = _tmp3_;
#line 299 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp4_ = g_strcmp0;
#line 299 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp5_ = _tmp4_ (str_a, str_b);
#line 299 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	result = _tmp5_;
#line 299 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (str_b);
#line 299 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (str_a);
#line 299 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return result;
#line 2006 "spice-display.c"
}


static gint _______lambda109__gcompare_func (gconstpointer a, gconstpointer b) {
	gint result;
	result = ______lambda109_ (a, b);
#line 295 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return result;
#line 2015 "spice-display.c"
}


static Block58Data* block58_data_ref (Block58Data* _data58_) {
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_atomic_int_inc (&_data58_->_ref_count_);
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return _data58_;
#line 2024 "spice-display.c"
}


static void block58_data_unref (void * _userdata_) {
	Block58Data* _data58_;
	_data58_ = (Block58Data*) _userdata_;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (g_atomic_int_dec_and_test (&_data58_->_ref_count_)) {
#line 2033 "spice-display.c"
		BoxesSpiceDisplay * self;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		self = _data58_->_data56_->_data55_->self;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (_data58_->dev_toggle);
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		__vala_SpiceUsbDevice_free0 (_data58_->dev);
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		block56_data_unref (_data58_->_data56_);
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_data58_->_data56_ = NULL;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_slice_free (Block58Data, _data58_);
#line 2047 "spice-display.c"
	}
}


static void ___lambda111_ (Block58Data* _data58_, GObject* obj, GAsyncResult* res) {
	Block56Data* _data56_;
	Block55Data* _data55_;
	BoxesSpiceDisplay * self;
	GError * _inner_error_ = NULL;
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_data56_ = _data58_->_data56_;
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_data55_ = _data56_->_data55_;
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = _data55_->self;
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (res != NULL);
#line 2065 "spice-display.c"
	{
		SpiceUsbDeviceManager* _tmp0_;
		GAsyncResult* _tmp1_;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp0_ = _data56_->manager;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp1_ = res;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		spice_usb_device_manager_connect_device_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_inner_error_ != NULL) {
#line 2077 "spice-display.c"
			goto __catch68_g_error;
		}
	}
	goto __finally68;
	__catch68_g_error:
	{
		GError* err = NULL;
		GtkSwitch* _tmp2_;
		SpiceUsbDevice* _tmp3_;
		gchar* _tmp4_ = NULL;
		gchar* device_desc;
		BoxesBoxConfig* _tmp5_;
		BoxesBoxConfig* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		const gchar* _tmp10_;
		const gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* box_name;
		const gchar* _tmp14_ = NULL;
		gchar* _tmp15_;
		gchar* msg;
		const gchar* _tmp16_;
		const gchar* _tmp17_;
		const gchar* _tmp18_;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_;
		const gchar* _tmp21_;
		const gchar* _tmp22_;
		GError* _tmp23_;
		const gchar* _tmp24_;
#line 316 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		err = _inner_error_;
#line 316 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 319 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp2_ = _data58_->dev_toggle;
#line 319 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		gtk_switch_set_active (_tmp2_, FALSE);
#line 320 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp3_ = _data58_->dev;
#line 320 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp4_ = spice_usb_device_get_description (_tmp3_, "%1$s %2$s");
#line 320 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		device_desc = _tmp4_;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp5_ = boxes_display_get_config ((BoxesDisplay*) self);
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp6_ = _tmp5_;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp7_ = boxes_box_config_get_last_seen_name (_tmp6_);
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp8_ = _tmp7_;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp9_ = _tmp8_;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp10_ = _tmp9_;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_tmp10_ == NULL) {
#line 2138 "spice-display.c"
			gchar* _tmp11_;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp11_ = g_strdup ("Unknown");
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_g_free0 (_tmp9_);
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp9_ = _tmp11_;
#line 2146 "spice-display.c"
		}
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp12_ = _tmp9_;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp13_ = g_strdup (_tmp12_);
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		box_name = _tmp13_;
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp14_ = _ ("Redirection of USB device '%s' for '%s' failed");
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp15_ = g_strdup (_tmp14_);
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		msg = _tmp15_;
#line 323 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp16_ = msg;
#line 323 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp17_ = device_desc;
#line 323 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp18_ = box_name;
#line 323 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp19_ = g_strdup_printf (_tmp16_, _tmp17_, _tmp18_);
#line 323 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp20_ = _tmp19_;
#line 323 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_signal_emit_by_name ((BoxesDisplay*) self, "got-error", _tmp20_);
#line 323 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp20_);
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp21_ = device_desc;
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp22_ = box_name;
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp23_ = err;
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp24_ = _tmp23_->message;
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_debug ("spice-display.vala:324: Error connecting %s to %s: %s", _tmp21_, _tmp22_, _tmp24_);
#line 316 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_free0 (msg);
#line 316 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_free0 (box_name);
#line 316 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp9_);
#line 316 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_free0 (device_desc);
#line 316 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (err);
#line 2194 "spice-display.c"
	}
	__finally68:
#line 316 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_inner_error_ != NULL) {
#line 316 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 316 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 316 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		return;
#line 2205 "spice-display.c"
	}
}


static void ____lambda111__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	___lambda111_ (self, source_object, res);
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	block58_data_unref (self);
#line 2215 "spice-display.c"
}


static void _________lambda110_ (Block58Data* _data58_) {
	Block56Data* _data56_;
	Block55Data* _data55_;
	BoxesSpiceDisplay * self;
	GtkSwitch* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 313 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_data56_ = _data58_->_data56_;
#line 313 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_data55_ = _data56_->_data55_;
#line 313 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = _data55_->self;
#line 314 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data58_->dev_toggle;
#line 314 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = gtk_switch_get_active (_tmp0_);
#line 314 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 314 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp2_) {
#line 2240 "spice-display.c"
		SpiceUsbDeviceManager* _tmp3_;
		SpiceUsbDevice* _tmp4_;
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp3_ = _data56_->manager;
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp4_ = _data58_->dev;
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		spice_usb_device_manager_connect_device_async (_tmp3_, _tmp4_, NULL, ____lambda111__gasync_ready_callback, block58_data_ref (_data58_));
#line 2249 "spice-display.c"
	} else {
		SpiceUsbDeviceManager* _tmp5_;
		SpiceUsbDevice* _tmp6_;
#line 328 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp5_ = _data56_->manager;
#line 328 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp6_ = _data58_->dev;
#line 328 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		spice_usb_device_manager_disconnect_device (_tmp5_, _tmp6_);
#line 2259 "spice-display.c"
	}
}


static void __________lambda110__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 313 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_________lambda110_ (self);
#line 2267 "spice-display.c"
}


static void ______lambda112_ (Block56Data* _data56_, SpiceUsbDeviceManager* manager, SpiceUsbDevice* dev) {
	Block55Data* _data55_;
	BoxesSpiceDisplay * self;
	BoxesProperty* _tmp0_;
#line 332 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_data55_ = _data56_->_data55_;
#line 332 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = _data55_->self;
#line 332 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (manager != NULL);
#line 332 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (dev != NULL);
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data55_->usb_property;
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_signal_emit_by_name (_tmp0_, "refresh-properties");
#line 2287 "spice-display.c"
}


static void _______lambda112__spice_usb_device_manager_device_added (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, gpointer self) {
#line 332 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	______lambda112_ (self, _sender, device);
#line 2294 "spice-display.c"
}


static gboolean __lambda114_ (Block56Data* _data56_) {
	Block55Data* _data55_;
	BoxesSpiceDisplay * self;
	gboolean result = FALSE;
	BoxesProperty* _tmp0_;
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_data55_ = _data56_->_data55_;
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = _data55_->self;
#line 341 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = _data55_->usb_property;
#line 341 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_signal_emit_by_name (_tmp0_, "refresh-properties");
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	result = FALSE;
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return result;
#line 2315 "spice-display.c"
}


static gboolean ___lambda114__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda114_ (self);
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return result;
#line 2324 "spice-display.c"
}


static void ______lambda113_ (Block56Data* _data56_, SpiceUsbDeviceManager* manager, SpiceUsbDevice* dev) {
	Block55Data* _data55_;
	BoxesSpiceDisplay * self;
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_data55_ = _data56_->_data55_;
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = _data55_->self;
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (manager != NULL);
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (dev != NULL);
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda114__gsource_func, block56_data_ref (_data56_), block56_data_unref);
#line 2341 "spice-display.c"
}


static void _______lambda113__spice_usb_device_manager_device_removed (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, gpointer self) {
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	______lambda113_ (self, _sender, device);
#line 2348 "spice-display.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 2355 "spice-display.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_list_free (self);
#line 2364 "spice-display.c"
}


static GList* boxes_spice_display_real_get_properties (BoxesDisplay* base, BoxesPropertiesPage page, PropertyCreationFlag* flags) {
	BoxesSpiceDisplay * self;
	GList* result = NULL;
	GList* list;
	BoxesPropertiesPage _tmp0_;
	GError * _inner_error_ = NULL;
#line 264 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 265 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	list = NULL;
#line 267 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = page;
#line 267 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	switch (_tmp0_) {
#line 267 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		case BOXES_PROPERTIES_PAGE_DISPLAY:
#line 2384 "spice-display.c"
		{
			GtkSwitch* _tmp1_;
			GtkSwitch* toggle;
			SpiceGtkSession* _tmp2_;
			GtkSwitch* _tmp3_;
			GtkSwitch* _tmp4_;
			const gchar* _tmp5_ = NULL;
			GtkSwitch* _tmp6_;
			BoxesProperty* _tmp7_ = NULL;
			BoxesProperty* _tmp8_;
			GtkSwitch* _tmp9_;
			GtkSwitch* _tmp10_;
			GtkSwitch* _tmp11_;
			const gchar* _tmp12_ = NULL;
			GtkSwitch* _tmp13_;
			BoxesProperty* _tmp14_ = NULL;
			BoxesProperty* _tmp15_;
#line 269 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp1_ = (GtkSwitch*) gtk_switch_new ();
#line 269 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			g_object_ref_sink (_tmp1_);
#line 269 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			toggle = _tmp1_;
#line 270 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp2_ = self->priv->gtk_session;
#line 270 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp3_ = toggle;
#line 270 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			g_object_bind_property_with_closures ((GObject*) _tmp2_, "auto-clipboard", (GObject*) _tmp3_, "active", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 272 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp4_ = toggle;
#line 272 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			gtk_widget_set_halign ((GtkWidget*) _tmp4_, GTK_ALIGN_START);
#line 273 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp5_ = _ ("Share clipboard");
#line 273 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp6_ = toggle;
#line 273 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp7_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp5_, (GtkWidget*) _tmp6_, NULL);
#line 273 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp8_ = _tmp7_;
#line 273 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (_tmp8_);
#line 275 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp9_ = (GtkSwitch*) gtk_switch_new ();
#line 275 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			g_object_ref_sink (_tmp9_);
#line 275 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (toggle);
#line 275 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			toggle = _tmp9_;
#line 276 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp10_ = toggle;
#line 276 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			g_object_bind_property_with_closures ((GObject*) self, "resize-guest", (GObject*) _tmp10_, "active", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp11_ = toggle;
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			gtk_widget_set_halign ((GtkWidget*) _tmp11_, GTK_ALIGN_START);
#line 279 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp12_ = _ ("Resize guest");
#line 279 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp13_ = toggle;
#line 279 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp14_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp12_, (GtkWidget*) _tmp13_, NULL);
#line 279 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp15_ = _tmp14_;
#line 279 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (_tmp15_);
#line 280 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_g_object_unref0 (toggle);
#line 280 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			break;
#line 2458 "spice-display.c"
		}
#line 267 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		case BOXES_PROPERTIES_PAGE_DEVICES:
#line 2462 "spice-display.c"
		{
			gboolean _tmp16_ = FALSE;
			PropertyCreationFlag _tmp17_;
			gboolean _tmp18_;
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp17_ = *flags;
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			if (!((_tmp17_ & PROPERTY_CREATION_FLAG_NO_USB) == PROPERTY_CREATION_FLAG_NO_USB)) {
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_tmp16_ = HAVE_USBREDIR;
#line 2473 "spice-display.c"
			} else {
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_tmp16_ = FALSE;
#line 2477 "spice-display.c"
			}
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp18_ = _tmp16_;
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			if (_tmp18_) {
#line 2483 "spice-display.c"
				Block55Data* _data55_;
				GtkSwitch* _tmp19_;
				GtkSwitch* toggle;
				SpiceGtkSession* _tmp20_;
				GtkSwitch* _tmp21_;
				GtkSwitch* _tmp22_;
				const gchar* _tmp23_ = NULL;
				GtkSwitch* _tmp24_;
				BoxesProperty* _tmp25_ = NULL;
				gboolean _tmp26_;
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_data55_ = g_slice_new0 (Block55Data);
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_data55_->_ref_count_ = 1;
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_data55_->self = g_object_ref (self);
#line 284 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_tmp19_ = (GtkSwitch*) gtk_switch_new ();
#line 284 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				g_object_ref_sink (_tmp19_);
#line 284 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				toggle = _tmp19_;
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_tmp20_ = self->priv->gtk_session;
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_tmp21_ = toggle;
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				g_object_bind_property_with_closures ((GObject*) _tmp20_, "auto-usbredir", (GObject*) _tmp21_, "active", G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 287 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_tmp22_ = toggle;
#line 287 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				gtk_widget_set_halign ((GtkWidget*) _tmp22_, GTK_ALIGN_START);
#line 288 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_tmp23_ = _ ("Redirect new USB devices");
#line 288 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_tmp24_ = toggle;
#line 288 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_tmp25_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp23_, (GtkWidget*) _tmp24_, NULL);
#line 288 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_data55_->usb_property = _tmp25_;
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_tmp26_ = self->priv->connected;
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				if (_tmp26_) {
#line 2528 "spice-display.c"
					gboolean found_dev;
#line 291 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					found_dev = FALSE;
#line 2532 "spice-display.c"
					{
						Block56Data* _data56_;
						SpiceSession* _tmp27_;
						SpiceUsbDeviceManager* _tmp28_ = NULL;
						SpiceUsbDeviceManager* _tmp29_;
						SpiceUsbDeviceManager* _tmp30_;
						GPtrArray* _tmp31_ = NULL;
						GPtrArray* devs;
						GPtrArray* _tmp32_;
						SpiceUsbDeviceManager* _tmp62_;
						SpiceUsbDeviceManager* _tmp63_;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_data56_ = g_slice_new0 (Block56Data);
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_data56_->_ref_count_ = 1;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_data56_->_data55_ = block55_data_ref (_data55_);
#line 293 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_tmp27_ = self->priv->session;
#line 293 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_tmp28_ = spice_usb_device_manager_get (_tmp27_, &_inner_error_);
#line 293 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_tmp29_ = _g_object_ref0 (_tmp28_);
#line 293 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_data56_->manager = _tmp29_;
#line 293 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						if (_inner_error_ != NULL) {
#line 293 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
							block56_data_unref (_data56_);
#line 293 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
							_data56_ = NULL;
#line 2564 "spice-display.c"
							goto __catch67_g_error;
						}
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_tmp30_ = _data56_->manager;
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_tmp31_ = spice_usb_device_manager_get_devices (_tmp30_);
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						devs = _tmp31_;
#line 295 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_tmp32_ = devs;
#line 295 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						vala_g_ptr_array_sort (_tmp32_, _______lambda109__gcompare_func);
#line 2577 "spice-display.c"
						{
							gint i;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
							i = 0;
#line 2582 "spice-display.c"
							{
								gboolean _tmp33_;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
								_tmp33_ = TRUE;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
								while (TRUE) {
#line 2589 "spice-display.c"
									Block58Data* _data58_;
									gboolean _tmp34_;
									gint _tmp36_;
									GPtrArray* _tmp37_;
									gint _tmp38_;
									gint _tmp39_;
									GPtrArray* _tmp40_;
									gint _tmp41_;
									gconstpointer _tmp42_ = NULL;
									SpiceUsbDevice* _tmp43_;
									GtkSwitch* _tmp44_;
									GtkSwitch* _tmp45_;
									gboolean _tmp46_;
									SpiceUsbDevice* _tmp51_;
									gchar* _tmp52_ = NULL;
									gchar* _tmp53_;
									GtkSwitch* _tmp54_;
									BoxesProperty* _tmp55_ = NULL;
									BoxesProperty* _tmp56_;
									GtkSwitch* _tmp57_;
									SpiceUsbDeviceManager* _tmp58_;
									SpiceUsbDevice* _tmp59_;
									gboolean _tmp60_ = FALSE;
									GtkSwitch* _tmp61_;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_data58_ = g_slice_new0 (Block58Data);
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_data58_->_ref_count_ = 1;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_data58_->_data56_ = block56_data_ref (_data56_);
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp34_ = _tmp33_;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									if (!_tmp34_) {
#line 2624 "spice-display.c"
										gint _tmp35_;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
										_tmp35_ = i;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
										i = _tmp35_ + 1;
#line 2630 "spice-display.c"
									}
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp33_ = FALSE;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp36_ = i;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp37_ = devs;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp38_ = g_ptr_array_get_length (_tmp37_);
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp39_ = _tmp38_;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									if (!(_tmp36_ < _tmp39_)) {
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
										block58_data_unref (_data58_);
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
										_data58_ = NULL;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
										break;
#line 2650 "spice-display.c"
									}
#line 302 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp40_ = devs;
#line 302 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp41_ = i;
#line 302 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp42_ = g_ptr_array_index (_tmp40_, (guint) _tmp41_);
#line 302 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp43_ = __vala_SpiceUsbDevice_copy0 ((SpiceUsbDevice*) _tmp42_);
#line 302 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_data58_->dev = _tmp43_;
#line 304 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp44_ = (GtkSwitch*) gtk_switch_new ();
#line 304 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									g_object_ref_sink (_tmp44_);
#line 304 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_data58_->dev_toggle = _tmp44_;
#line 305 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp45_ = _data58_->dev_toggle;
#line 305 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									gtk_widget_set_halign ((GtkWidget*) _tmp45_, GTK_ALIGN_START);
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp46_ = found_dev;
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									if (!_tmp46_) {
#line 2676 "spice-display.c"
										GtkLabel* _tmp47_;
										GtkLabel* _tmp48_;
										BoxesProperty* _tmp49_ = NULL;
										BoxesProperty* _tmp50_;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
										_tmp47_ = (GtkLabel*) gtk_label_new ("");
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
										g_object_ref_sink (_tmp47_);
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
										_tmp48_ = _tmp47_;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
										_tmp49_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, "USB devices", (GtkWidget*) _tmp48_, NULL);
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
										_tmp50_ = _tmp49_;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
										_g_object_unref0 (_tmp50_);
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
										_g_object_unref0 (_tmp48_);
#line 2695 "spice-display.c"
									}
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									found_dev = TRUE;
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp51_ = _data58_->dev;
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp52_ = spice_usb_device_get_description (_tmp51_, "    %1$s %2$s");
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp53_ = _tmp52_;
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp54_ = _data58_->dev_toggle;
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp55_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp53_, (GtkWidget*) _tmp54_, NULL);
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp56_ = _tmp55_;
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_g_object_unref0 (_tmp56_);
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_g_free0 (_tmp53_);
#line 311 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp57_ = _data58_->dev_toggle;
#line 311 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp58_ = _data56_->manager;
#line 311 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp59_ = _data58_->dev;
#line 311 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp60_ = spice_usb_device_manager_is_device_connected (_tmp58_, _tmp59_);
#line 311 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									gtk_switch_set_active (_tmp57_, _tmp60_);
#line 313 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_tmp61_ = _data58_->dev_toggle;
#line 313 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									g_signal_connect_data ((GObject*) _tmp61_, "notify::active", (GCallback) __________lambda110__g_object_notify, block58_data_ref (_data58_), (GClosureNotify) block58_data_unref, 0);
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									block58_data_unref (_data58_);
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
									_data58_ = NULL;
#line 2733 "spice-display.c"
								}
							}
						}
#line 332 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_tmp62_ = _data56_->manager;
#line 332 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						g_signal_connect_data (_tmp62_, "device-added", (GCallback) _______lambda112__spice_usb_device_manager_device_added, block56_data_ref (_data56_), (GClosureNotify) block56_data_unref, 0);
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_tmp63_ = _data56_->manager;
#line 335 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						g_signal_connect_data (_tmp63_, "device-removed", (GCallback) _______lambda113__spice_usb_device_manager_device_removed, block56_data_ref (_data56_), (GClosureNotify) block56_data_unref, 0);
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_g_ptr_array_unref0 (devs);
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						block56_data_unref (_data56_);
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_data56_ = NULL;
#line 2751 "spice-display.c"
					}
					goto __finally67;
					__catch67_g_error:
					{
						GError* _error_ = NULL;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_error_ = _inner_error_;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_inner_error_ = NULL;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_g_error_free0 (_error_);
#line 2763 "spice-display.c"
					}
					__finally67:
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					if (_inner_error_ != NULL) {
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_g_object_unref0 (toggle);
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						block55_data_unref (_data55_);
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						_data55_ = NULL;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						__g_list_free__g_object_unref0_0 (list);
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						g_clear_error (&_inner_error_);
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
						return NULL;
#line 2782 "spice-display.c"
					}
				}
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_g_object_unref0 (toggle);
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				block55_data_unref (_data55_);
#line 283 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_data55_ = NULL;
#line 2791 "spice-display.c"
			}
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			break;
#line 2795 "spice-display.c"
		}
		default:
#line 267 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		break;
#line 2800 "spice-display.c"
	}
#line 352 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	result = list;
#line 352 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return result;
#line 2806 "spice-display.c"
}


static const gchar* boxes_spice_display_real_get_protocol (BoxesDisplay* base) {
	const gchar* result;
	BoxesSpiceDisplay* self;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	result = "SPICE";
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return result;
#line 2819 "spice-display.c"
}


static gchar* boxes_spice_display_real_get_uri (BoxesDisplay* base) {
	gchar* result;
	BoxesSpiceDisplay* self;
	SpiceSession* _tmp0_;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = (BoxesSpiceDisplay*) base;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp0_, "uri", &_tmp1_, NULL);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	result = _tmp2_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return result;
#line 2841 "spice-display.c"
}


GByteArray* boxes_spice_display_get_ca_cert (BoxesSpiceDisplay* self) {
	GByteArray* result;
	SpiceSession* _tmp0_;
	GByteArray* _tmp1_ = NULL;
	GByteArray* _tmp2_;
#line 8 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 8 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 8 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_get (_tmp0_, "ca", &_tmp1_, NULL);
#line 8 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = _tmp1_;
#line 8 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	result = _tmp2_;
#line 8 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return result;
#line 2862 "spice-display.c"
}


void boxes_spice_display_set_ca_cert (BoxesSpiceDisplay* self, GByteArray* value) {
	SpiceSession* _tmp0_;
	GByteArray* _tmp1_;
#line 8 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 8 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->session;
#line 8 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = value;
#line 8 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_set (_tmp0_, "ca", _tmp1_, NULL);
#line 8 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_notify ((GObject *) self, "ca-cert");
#line 2879 "spice-display.c"
}


gboolean boxes_spice_display_get_resize_guest (BoxesSpiceDisplay* self) {
	gboolean result;
	gboolean _tmp0_;
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = self->priv->_resize_guest;
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	result = _tmp0_;
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return result;
#line 2894 "spice-display.c"
}


void boxes_spice_display_set_resize_guest (BoxesSpiceDisplay* self, gboolean value) {
	gboolean _tmp0_;
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (self != NULL);
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = value;
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->_resize_guest = _tmp0_;
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_notify ((GObject *) self, "resize-guest");
#line 2908 "spice-display.c"
}


static void _boxes_spice_display____lambda115_ (BoxesSpiceDisplay* self, SpiceUsbDevice* dev, GError* err) {
	SpiceUsbDevice* _tmp0_;
	gchar* _tmp1_ = NULL;
	gchar* device_description;
	BoxesBoxConfig* _tmp2_;
	BoxesBoxConfig* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* box_name;
	const gchar* _tmp11_ = NULL;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	gchar* _tmp14_ = NULL;
	gchar* _tmp15_;
	const gchar* _tmp16_;
	const gchar* _tmp17_;
	GError* _tmp18_;
	const gchar* _tmp19_;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (dev != NULL);
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = dev;
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = spice_usb_device_get_description (_tmp0_, "%1$s %2$s");
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	device_description = _tmp1_;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = boxes_display_get_config ((BoxesDisplay*) self);
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp3_ = _tmp2_;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp4_ = boxes_box_config_get_last_seen_name (_tmp3_);
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp5_ = _tmp4_;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp6_ = _tmp5_;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp7_ = _tmp6_;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp7_ == NULL) {
#line 2956 "spice-display.c"
		gchar* _tmp8_;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp8_ = g_strdup ("Unknown");
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp6_);
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp6_ = _tmp8_;
#line 2964 "spice-display.c"
	}
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp9_ = _tmp6_;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp10_ = g_strdup (_tmp9_);
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	box_name = _tmp10_;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp11_ = _ ("Automatic redirection of USB device '%s' for '%s' failed");
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp12_ = device_description;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp13_ = box_name;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp14_ = g_strdup_printf (_tmp11_, _tmp12_, _tmp13_);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp15_ = _tmp14_;
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_signal_emit_by_name ((BoxesDisplay*) self, "got-error", _tmp15_);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp15_);
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp16_ = device_description;
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp17_ = box_name;
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp18_ = err;
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp19_ = _tmp18_->message;
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_debug ("spice-display.vala:52: Error auto-connecting %s for %s: %s", _tmp16_, _tmp17_, _tmp19_);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (box_name);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp6_);
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (device_description);
#line 3002 "spice-display.c"
}


static void __boxes_spice_display____lambda115__spice_usb_device_manager_auto_connect_failed (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, GError* _error_, gpointer self) {
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_boxes_spice_display____lambda115_ (self, device, _error_);
#line 3009 "spice-display.c"
}


static void _boxes_spice_display____lambda116_ (BoxesSpiceDisplay* self, SpiceUsbDevice* dev, GError* err) {
	SpiceUsbDevice* _tmp0_;
	gchar* _tmp1_ = NULL;
	gchar* device_description;
	BoxesBoxConfig* _tmp2_;
	BoxesBoxConfig* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* box_name;
	const gchar* _tmp11_ = NULL;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	gchar* _tmp14_ = NULL;
	gchar* _tmp15_;
	const gchar* _tmp16_;
	const gchar* _tmp17_;
	GError* _tmp18_;
	const gchar* _tmp19_;
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (dev != NULL);
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = dev;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = spice_usb_device_get_description (_tmp0_, "%1$s %2$s");
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	device_description = _tmp1_;
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = boxes_display_get_config ((BoxesDisplay*) self);
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp3_ = _tmp2_;
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp4_ = boxes_box_config_get_last_seen_name (_tmp3_);
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp5_ = _tmp4_;
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp6_ = _tmp5_;
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp7_ = _tmp6_;
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp7_ == NULL) {
#line 3057 "spice-display.c"
		gchar* _tmp8_;
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp8_ = g_strdup ("Unknown");
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp6_);
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp6_ = _tmp8_;
#line 3065 "spice-display.c"
	}
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp9_ = _tmp6_;
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp10_ = g_strdup (_tmp9_);
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	box_name = _tmp10_;
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp11_ = _ ("Redirection of USB device '%s' for '%s' failed");
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp12_ = device_description;
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp13_ = box_name;
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp14_ = g_strdup_printf (_tmp11_, _tmp12_, _tmp13_);
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp15_ = _tmp14_;
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_signal_emit_by_name ((BoxesDisplay*) self, "got-error", _tmp15_);
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp15_);
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp16_ = device_description;
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp17_ = box_name;
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp18_ = err;
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp19_ = _tmp18_->message;
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_debug ("spice-display.vala:59: Error connecting %s to %s: %s", _tmp16_, _tmp17_, _tmp19_);
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (box_name);
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp6_);
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (device_description);
#line 3103 "spice-display.c"
}


static void __boxes_spice_display____lambda116__spice_usb_device_manager_device_error (SpiceUsbDeviceManager* _sender, SpiceUsbDevice* device, GError* _error_, gpointer self) {
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_boxes_spice_display____lambda116_ (self, device, _error_);
#line 3110 "spice-display.c"
}


static void _boxes_spice_display___lambda117_ (BoxesSpiceDisplay* self) {
	BoxesBoxConfig* _tmp0_;
	BoxesBoxConfig* _tmp1_;
	SpiceGtkSession* _tmp2_;
	BoxesBoxConfigSyncProperty* _tmp3_;
	gint _tmp3__length1;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = boxes_display_get_config ((BoxesDisplay*) self);
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = _tmp0_;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = self->priv->gtk_session;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp3_ = self->priv->gtk_session_sync_properties;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp3__length1 = self->priv->gtk_session_sync_properties_length1;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	boxes_box_config_sync_properties (_tmp1_, (GObject*) _tmp2_, _tmp3_, _tmp3__length1);
#line 3132 "spice-display.c"
}


static void __boxes_spice_display___lambda117__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_boxes_spice_display___lambda117_ (self);
#line 3139 "spice-display.c"
}


static void _boxes_spice_display_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_ui_state_changed (self);
#line 3146 "spice-display.c"
}


static GObject * boxes_spice_display_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesSpiceDisplay * self;
	gchar* _tmp0_;
	GValue _tmp1_ = {0};
	BoxesBoxConfigSyncProperty _tmp2_ = {0};
	BoxesBoxConfigSyncProperty* _tmp3_ = NULL;
	gchar* _tmp4_;
	GValue _tmp5_ = {0};
	BoxesBoxConfigSyncProperty _tmp6_ = {0};
	gchar* _tmp7_;
	GValue _tmp8_ = {0};
	BoxesBoxConfigSyncProperty _tmp9_ = {0};
	BoxesBoxConfigSyncProperty* _tmp10_ = NULL;
	SpiceSession* _tmp11_;
	SpiceSession* _tmp12_;
	SpiceAudio* _tmp13_ = NULL;
	SpiceSession* _tmp14_;
	SpiceGtkSession* _tmp15_ = NULL;
	BoxesApp* _tmp21_;
	GError * _inner_error_ = NULL;
#line 31 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	parent_class = G_OBJECT_CLASS (boxes_spice_display_parent_class);
#line 31 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 31 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay);
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = g_strdup ("resize-guest");
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_value_init (&_tmp1_, G_TYPE_BOOLEAN);
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_value_set_boolean (&_tmp1_, TRUE);
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	memset (&_tmp2_, 0, sizeof (BoxesBoxConfigSyncProperty));
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp2_.name);
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_.name = _tmp0_;
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	G_IS_VALUE (&_tmp2_.default_value) ? (g_value_unset (&_tmp2_.default_value), NULL) : NULL;
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_.default_value = _tmp1_;
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp3_ = g_new0 (BoxesBoxConfigSyncProperty, 1);
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp3_[0] = _tmp2_;
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->display_sync_properties = (_vala_BoxesBoxConfigSyncProperty_array_free (self->priv->display_sync_properties, self->priv->display_sync_properties_length1), NULL);
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->display_sync_properties = _tmp3_;
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->display_sync_properties_length1 = 1;
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->_display_sync_properties_size_ = self->priv->display_sync_properties_length1;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp4_ = g_strdup ("auto-clipboard");
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_value_init (&_tmp5_, G_TYPE_BOOLEAN);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_value_set_boolean (&_tmp5_, TRUE);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	memset (&_tmp6_, 0, sizeof (BoxesBoxConfigSyncProperty));
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp6_.name);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp6_.name = _tmp4_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	G_IS_VALUE (&_tmp6_.default_value) ? (g_value_unset (&_tmp6_.default_value), NULL) : NULL;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp6_.default_value = _tmp5_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp7_ = g_strdup ("auto-usbredir");
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_value_init (&_tmp8_, G_TYPE_BOOLEAN);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_value_set_boolean (&_tmp8_, FALSE);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	memset (&_tmp9_, 0, sizeof (BoxesBoxConfigSyncProperty));
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp9_.name);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp9_.name = _tmp7_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	G_IS_VALUE (&_tmp9_.default_value) ? (g_value_unset (&_tmp9_.default_value), NULL) : NULL;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp9_.default_value = _tmp8_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp10_ = g_new0 (BoxesBoxConfigSyncProperty, 2);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp10_[0] = _tmp6_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp10_[1] = _tmp9_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session_sync_properties = (_vala_BoxesBoxConfigSyncProperty_array_free (self->priv->gtk_session_sync_properties, self->priv->gtk_session_sync_properties_length1), NULL);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session_sync_properties = _tmp10_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session_sync_properties_length1 = 2;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->_gtk_session_sync_properties_size_ = self->priv->gtk_session_sync_properties_length1;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	boxes_display_set_need_password ((BoxesDisplay*) self, FALSE);
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp11_ = spice_session_new ();
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->session);
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->session = _tmp11_;
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp12_ = self->priv->session;
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp13_ = spice_audio_get (_tmp12_, NULL);
#line 43 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->audio = _tmp13_;
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp14_ = self->priv->session;
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp15_ = spice_gtk_session_get (_tmp14_);
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session = _tmp15_;
#line 3272 "spice-display.c"
	{
		SpiceSession* _tmp16_;
		SpiceUsbDeviceManager* _tmp17_ = NULL;
		SpiceUsbDeviceManager* _tmp18_;
		SpiceUsbDeviceManager* manager;
		SpiceUsbDeviceManager* _tmp19_;
		SpiceUsbDeviceManager* _tmp20_;
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp16_ = self->priv->session;
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp17_ = spice_usb_device_manager_get (_tmp16_, &_inner_error_);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp18_ = _g_object_ref0 (_tmp17_);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		manager = _tmp18_;
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_inner_error_ != NULL) {
#line 3290 "spice-display.c"
			goto __catch69_g_error;
		}
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp19_ = manager;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_signal_connect_object (_tmp19_, "auto-connect-failed", (GCallback) __boxes_spice_display____lambda115__spice_usb_device_manager_auto_connect_failed, self, 0);
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp20_ = manager;
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_signal_connect_object (_tmp20_, "device-error", (GCallback) __boxes_spice_display____lambda116__spice_usb_device_manager_device_error, self, 0);
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (manager);
#line 3303 "spice-display.c"
	}
	goto __finally69;
	__catch69_g_error:
	{
		GError* _error_ = NULL;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_error_ = _inner_error_;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_inner_error_ = NULL;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_error_free0 (_error_);
#line 3315 "spice-display.c"
	}
	__finally69:
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_inner_error_ != NULL) {
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_clear_error (&_inner_error_);
#line 3324 "spice-display.c"
	}
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_signal_connect_object ((GObject*) self, "notify::config", (GCallback) __boxes_spice_display___lambda117__g_object_notify, self, 0);
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp21_ = boxes_app_app;
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_signal_connect_object ((GObject*) _tmp21_, "notify::ui-state", (GCallback) _boxes_spice_display_ui_state_changed_g_object_notify, self, 0);
#line 31 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return obj;
#line 3334 "spice-display.c"
}


static void boxes_spice_display_class_init (BoxesSpiceDisplayClass * klass) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_type_class_add_private (klass, sizeof (BoxesSpiceDisplayPrivate));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_display = boxes_spice_display_real_get_display;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->should_keep_alive = boxes_spice_display_real_should_keep_alive;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->set_enable_audio = boxes_spice_display_real_set_enable_audio;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->set_enable_inputs = boxes_spice_display_real_set_enable_inputs;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_pixbuf = boxes_spice_display_real_get_pixbuf;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->collect_logs = boxes_spice_display_real_collect_logs;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->connect_it = boxes_spice_display_real_connect_it;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->disconnect_it = boxes_spice_display_real_disconnect_it;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_properties = boxes_spice_display_real_get_properties;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_protocol = boxes_spice_display_real_get_protocol;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_uri = boxes_spice_display_real_get_uri;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_spice_display_get_property;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_spice_display_set_property;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_spice_display_constructor;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_spice_display_finalize;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SPICE_DISPLAY_PROTOCOL, g_param_spec_string ("protocol", "protocol", "protocol", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SPICE_DISPLAY_URI, g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SPICE_DISPLAY_CA_CERT, g_param_spec_boxed ("ca-cert", "ca-cert", "ca-cert", G_TYPE_BYTE_ARRAY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SPICE_DISPLAY_RESIZE_GUEST, g_param_spec_boolean ("resize-guest", "resize-guest", "resize-guest", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3381 "spice-display.c"
}


static void boxes_spice_display_instance_init (BoxesSpiceDisplay * self) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv = BOXES_SPICE_DISPLAY_GET_PRIVATE (self);
#line 3388 "spice-display.c"
}


static void boxes_spice_display_finalize (GObject* obj) {
	BoxesSpiceDisplay * self;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay);
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	boxes_spice_display_main_cleanup (self);
#line 10 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->session);
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->display_sync_properties = (_vala_BoxesBoxConfigSyncProperty_array_free (self->priv->display_sync_properties, self->priv->display_sync_properties_length1), NULL);
#line 16 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	self->priv->gtk_session_sync_properties = (_vala_BoxesBoxConfigSyncProperty_array_free (self->priv->gtk_session_sync_properties, self->priv->gtk_session_sync_properties_length1), NULL);
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_object_unref0 (self->priv->main_channel);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	G_OBJECT_CLASS (boxes_spice_display_parent_class)->finalize (obj);
#line 3408 "spice-display.c"
}


GType boxes_spice_display_get_type (void) {
	static volatile gsize boxes_spice_display_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_spice_display_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSpiceDisplayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_spice_display_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSpiceDisplay), 0, (GInstanceInitFunc) boxes_spice_display_instance_init, NULL };
		GType boxes_spice_display_type_id;
		boxes_spice_display_type_id = g_type_register_static (BOXES_TYPE_DISPLAY, "BoxesSpiceDisplay", &g_define_type_info, 0);
		g_once_init_leave (&boxes_spice_display_type_id__volatile, boxes_spice_display_type_id);
	}
	return boxes_spice_display_type_id__volatile;
}


static void _vala_boxes_spice_display_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesSpiceDisplay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	switch (property_id) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_PROTOCOL:
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_value_set_string (value, boxes_display_get_protocol ((BoxesDisplay*) self));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		break;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_URI:
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_value_take_string (value, boxes_display_get_uri ((BoxesDisplay*) self));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		break;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_CA_CERT:
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_value_take_boxed (value, boxes_spice_display_get_ca_cert (self));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		break;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_RESIZE_GUEST:
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		g_value_set_boolean (value, boxes_spice_display_get_resize_guest (self));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		break;
#line 3453 "spice-display.c"
		default:
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		break;
#line 3459 "spice-display.c"
	}
}


static void _vala_boxes_spice_display_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesSpiceDisplay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	switch (property_id) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_CA_CERT:
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		boxes_spice_display_set_ca_cert (self, g_value_get_boxed (value));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		break;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		case BOXES_SPICE_DISPLAY_RESIZE_GUEST:
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		boxes_spice_display_set_resize_guest (self, g_value_get_boolean (value));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		break;
#line 3481 "spice-display.c"
		default:
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		break;
#line 3487 "spice-display.c"
	}
}


static gint* _int_dup (gint* self) {
	gint* dup;
#line 365 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	dup = g_new0 (gint, 1);
#line 365 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	memcpy (dup, self, sizeof (gint));
#line 365 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return dup;
#line 3500 "spice-display.c"
}


static gpointer __int_dup0 (gpointer self) {
#line 365 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	return self ? _int_dup (self) : NULL;
#line 3507 "spice-display.c"
}


void spice_validate_uri (const gchar* uri_as_text, gint** port, gint** tls_port, GError** error) {
	gint* _vala_port = NULL;
	gint* _vala_tls_port = NULL;
	const gchar* _tmp0_;
	xmlURI* _tmp1_ = NULL;
	xmlURI* uri;
	xmlURI* _tmp2_;
	gint _tmp5_;
	gint* _tmp6_;
	xmlURI* _tmp7_;
	gint _tmp8_;
	gint* _tmp9_;
	xmlURI* _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	const gchar* _tmp14_;
	const gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* query_str;
	const gchar* _tmp20_;
	gboolean _tmp44_ = FALSE;
	gint* _tmp45_;
	gboolean _tmp47_;
	GError * _inner_error_ = NULL;
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	g_return_if_fail (uri_as_text != NULL);
#line 360 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp0_ = uri_as_text;
#line 360 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp1_ = xmlParseURI (_tmp0_);
#line 360 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	uri = _tmp1_;
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp2_ = uri;
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp2_ == NULL) {
#line 3548 "spice-display.c"
		const gchar* _tmp3_ = NULL;
		GError* _tmp4_;
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp3_ = _ ("Invalid URI");
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp4_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp3_);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_inner_error_ = _tmp4_;
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			g_propagate_error (error, _inner_error_);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_xmlFreeURI0 (uri);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			return;
#line 3565 "spice-display.c"
		} else {
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_xmlFreeURI0 (uri);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			g_clear_error (&_inner_error_);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			return;
#line 3575 "spice-display.c"
		}
	}
#line 365 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp5_ = 0;
#line 365 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp6_ = __int_dup0 (&_tmp5_);
#line 365 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (_vala_tls_port);
#line 365 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_vala_tls_port = _tmp6_;
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp7_ = uri;
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp8_ = _tmp7_->port;
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp9_ = __int_dup0 (&_tmp8_);
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (_vala_port);
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_vala_port = _tmp9_;
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp10_ = uri;
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp11_ = _tmp10_->query_raw;
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp12_ = g_strdup (_tmp11_);
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp13_ = _tmp12_;
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp14_ = _tmp13_;
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp14_ == NULL) {
#line 3608 "spice-display.c"
		xmlURI* _tmp15_;
		const gchar* _tmp16_;
		gchar* _tmp17_;
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp15_ = uri;
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp16_ = _tmp15_->query;
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp17_ = g_strdup (_tmp16_);
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp13_);
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp13_ = _tmp17_;
#line 3622 "spice-display.c"
	}
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp18_ = _tmp13_;
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp19_ = g_strdup (_tmp18_);
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	query_str = _tmp19_;
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp20_ = query_str;
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp20_ != NULL) {
#line 3634 "spice-display.c"
		const gchar* _tmp21_;
		BoxesQuery* _tmp22_;
		BoxesQuery* query;
		BoxesQuery* _tmp23_;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_;
		gboolean _tmp26_;
		BoxesQuery* _tmp35_;
		gchar* _tmp36_ = NULL;
		gchar* _tmp37_;
		gboolean _tmp38_;
#line 370 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp21_ = query_str;
#line 370 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp22_ = boxes_query_new (_tmp21_);
#line 370 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		query = _tmp22_;
#line 371 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp23_ = query;
#line 371 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp24_ = boxes_query_get (_tmp23_, "port");
#line 371 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp25_ = _tmp24_;
#line 371 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp26_ = _tmp25_ != NULL;
#line 371 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp25_);
#line 371 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_tmp26_) {
#line 3664 "spice-display.c"
			gint* _tmp27_;
			BoxesQuery* _tmp30_;
			gchar* _tmp31_ = NULL;
			gchar* _tmp32_;
			gint _tmp33_ = 0;
			gint* _tmp34_;
#line 372 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp27_ = _vala_port;
#line 372 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			if ((*_tmp27_) > 0) {
#line 3675 "spice-display.c"
				const gchar* _tmp28_ = NULL;
				GError* _tmp29_;
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_tmp28_ = _ ("The port must be specified once");
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_tmp29_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp28_);
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				_inner_error_ = _tmp29_;
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
				if (_inner_error_->domain == BOXES_ERROR) {
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					g_propagate_error (error, _inner_error_);
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_g_object_unref0 (query);
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_g_free0 (query_str);
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_g_free0 (_tmp13_);
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_xmlFreeURI0 (uri);
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					return;
#line 3698 "spice-display.c"
				} else {
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_g_object_unref0 (query);
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_g_free0 (query_str);
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_g_free0 (_tmp13_);
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					_xmlFreeURI0 (uri);
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					g_clear_error (&_inner_error_);
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
					return;
#line 3714 "spice-display.c"
				}
			}
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp30_ = query;
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp31_ = boxes_query_get (_tmp30_, "port");
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp32_ = _tmp31_;
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp33_ = atoi (_tmp32_);
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp34_ = __int_dup0 (&_tmp33_);
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_g_free0 (_vala_port);
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_vala_port = _tmp34_;
#line 374 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_g_free0 (_tmp32_);
#line 3733 "spice-display.c"
		}
#line 377 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp35_ = query;
#line 377 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp36_ = boxes_query_get (_tmp35_, "tls-port");
#line 377 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp37_ = _tmp36_;
#line 377 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp38_ = _tmp37_ != NULL;
#line 377 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_free0 (_tmp37_);
#line 377 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_tmp38_) {
#line 3747 "spice-display.c"
			BoxesQuery* _tmp39_;
			gchar* _tmp40_ = NULL;
			gchar* _tmp41_;
			gint _tmp42_ = 0;
			gint* _tmp43_;
#line 378 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp39_ = query;
#line 378 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp40_ = boxes_query_get (_tmp39_, "tls-port");
#line 378 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp41_ = _tmp40_;
#line 378 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp42_ = atoi (_tmp41_);
#line 378 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_tmp43_ = __int_dup0 (&_tmp42_);
#line 378 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_g_free0 (_vala_tls_port);
#line 378 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_vala_tls_port = _tmp43_;
#line 378 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_g_free0 (_tmp41_);
#line 3769 "spice-display.c"
		}
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_object_unref0 (query);
#line 3773 "spice-display.c"
	}
#line 381 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp45_ = _vala_port;
#line 381 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if ((*_tmp45_) <= 0) {
#line 3779 "spice-display.c"
		gint* _tmp46_;
#line 381 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp46_ = _vala_tls_port;
#line 381 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp44_ = (*_tmp46_) <= 0;
#line 3785 "spice-display.c"
	} else {
#line 381 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp44_ = FALSE;
#line 3789 "spice-display.c"
	}
#line 381 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_tmp47_ = _tmp44_;
#line 381 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (_tmp47_) {
#line 3795 "spice-display.c"
		const gchar* _tmp48_ = NULL;
		GError* _tmp49_;
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp48_ = _ ("Missing port in Spice URI");
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_tmp49_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp48_);
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_inner_error_ = _tmp49_;
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			g_propagate_error (error, _inner_error_);
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_g_free0 (query_str);
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_g_free0 (_tmp13_);
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_xmlFreeURI0 (uri);
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			return;
#line 3816 "spice-display.c"
		} else {
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_g_free0 (query_str);
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_g_free0 (_tmp13_);
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			_xmlFreeURI0 (uri);
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			g_clear_error (&_inner_error_);
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
			return;
#line 3830 "spice-display.c"
		}
	}
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (query_str);
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_g_free0 (_tmp13_);
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	_xmlFreeURI0 (uri);
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (port) {
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		*port = _vala_port;
#line 3843 "spice-display.c"
	} else {
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_free0 (_vala_port);
#line 3847 "spice-display.c"
	}
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
	if (tls_port) {
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		*tls_port = _vala_tls_port;
#line 3853 "spice-display.c"
	} else {
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/spice-display.vala"
		_g_free0 (_vala_tls_port);
#line 3857 "spice-display.c"
	}
}



